@@ -18,8 +18,6 @@ gamlr <- function(x, y,
             maxit=1e5,
             verb=FALSE, ...)
 {
-  on.exit(.C("gamlr_cleanup", PACKAGE = "gamlr"))
-
   ## integer family codes
   family=match.arg(family)
   famid = switch(family, 
@@ -167,7 +165,8 @@ gamlr <- function(x, y,
 
 
   ## drop it like it's hot
-  fit <- .C("gamlr",
+  on.exit(.C("R_gamlr_cleanup", PACKAGE = "gamlr"))
+  fit <- .C("R_gamlr",
             famid=as.integer(famid), 
             n=n,
             p=p,
@@ -312,10 +311,13 @@ plot.gamlr <- function(x, against=c("pen","dev"),
   }
 }
 
-coef.gamlr <- function(object, select=NULL, k=2, ...)
+coef.gamlr <- function(object, select=NULL, k=2, corrected=TRUE, ...)
 {
   if(length(select)==0){
-    select <- which.min(AICc(object,k=k))
+  	if(corrected)
+    	select <- which.min(AICc(object,k=k))
+    else
+    	select <- which.min(AIC(object,k=k))
     if(length(select)==0) select <- 1
   }
   else if(select==0)
